@@ -1,12 +1,13 @@
 #
-# $Id: String.pm,v 0.03 2004/01/02 03:35:03 st.schubiger Exp $
+# $Id: String.pm,v 0.04 2004/01/02 14:57:27 st.schubiger Exp $
 
 package Convert::ASCII::String;
 
 use strict;
 use warnings;
 
-require Exporter;
+use Carp;
+use Exporter;
 use base qw(Exporter);
 
 our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
@@ -15,7 +16,7 @@ our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ( 'all' => [ @subs ] );
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 =head1 NAME
 
@@ -61,7 +62,7 @@ remain within memory, then array ASCII conversion using I<pack> & I<unpack> is a
 presumably faster than using C<Convert::ASCII::String>.
 
 C<Convert::ASCII::String> uses I<join> & I<split> among I<pack> & I<unpack> to merge array to
-strings and vice versa. Thus wisely usage is recommended since such operations may slow down
+strings and vice versa. Thus wise usage is recommended since such operations may slow down
 converting if much data has be transformed. So, when to use then?
 
 Whenever data has to be converted to ASCII and has to be stored on a disk or other mediums
@@ -71,24 +72,45 @@ the array. Thus string transformation with an item separator.
 
 =head1 FUNCTIONS
 
-=head2 string2ascii ( \$data, $separator )
+=head2 string2ascii ( \$data, [$separator] )
 
 Convert a character string to ASCII inserting a separator between each ASCII code.
 
+The separator is optional.
+
     string2ascii (\$data, '.');
 
+    or
+
+    string2ascii (\$data);
+
+Beware, second option will not allow back converting from ASCII.
+
+=head3 RETURN CODES
+
+=over 4
+
+=item (0)
+
+Success.
+
+=item (1)
+
+No scalar reference provided.
+
+=back
+
 =cut
 
 sub string2ascii {
     my ($data_ref, $sep) = @_;
-    no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'};
-    unless (ref $data_ref eq 'SCALAR' && $sep) {
-        require Carp;
-        Carp::croak q~usage: string2ascii (\$data, $separator)~;
-    }
+    no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'} || '';
+    return 1 unless ref $data_ref eq 'SCALAR';
 
     my @ascii = unpack 'C*', $$data_ref;
     $$data_ref = join $sep, @ascii;
+
+    0;
 }
 
 =head2 ascii2string ( \$data, $separator )
@@ -97,33 +119,43 @@ And vice versa.
 
     ascii2string (\$data, '.');
 
+=head3 RETURN CODES
+
+=over 4
+
+=item (0)
+
+Success.
+
+=item (1)
+
+No scalar reference or separator provided.
+
+=item (2)
+
+Separator mismatch.
+
+=back
+
 =cut
 
 sub ascii2string {
     my ($data_ref, $sep) = @_;
     no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'};
-    unless (ref $data_ref eq 'SCALAR' && $sep) {
-        require Carp;
-        Carp::croak q~usage: ascii2string (\$data, $separator)~;
-    }
-
+    return 1 unless ref $data_ref eq 'SCALAR' && $sep;
     $sep = quotemeta $sep;
+    return 2 if $$data_ref !~ /$sep/i;
+
     my @ascii = split $sep, $$data_ref;
-    $$data_ref = pack 'C*', @ascii;      
+    $$data_ref = pack 'C*', @ascii;
+
+    0;
 }
 
 1;
 __END__
 
-=head2 EXPORT
-
-C<string2ascii()> and C<ascii2string()> upon request.
-
-=head3 TAGS
-
-:all - C<*()>
-
-=head1 OPTIONS
+=head2 OPTIONS
 
 The separator may alternatively be set by
 
@@ -131,6 +163,14 @@ The separator may alternatively be set by
 
 Function delivery becomes then superfluous.
 
+=head1 EXPORT
+
+C<string2ascii()> and C<ascii2string()> upon request.
+
+=head2 TAGS
+
+:all - C<*()>
+
 =head1 SEE ALSO
 
 perl(1)
